#pragma once

namespace AMDiS
{
#ifdef DOXYGEN
  /**
   *  Base traits class for a linear solver for the system AX=B using an FE space described by a
   *  dune-functions Basis. This defines the general interface typedefs, all implementations are
   *  required to provide the typedefs listed here.
   *
   *  \tparam Basis  A global basis from dune-functions
   *  \tparam T      The type of the coefficients stored inthe matrix and vector
   */
  template <class Basis, class T = double>
  class BackendTraits
  {
  public:
    using Mat = implementation_defined;   //< The backend matrix type
    using Vec = implementation_defined;   //< The backend vector type
    using Comm = implementation_defined;  //< The communication type

    using CoefficientType = T;                   //< The type of the matrix/vector entries
    using PartitionSet = Dune::Partitions::All;  //< The dune partition set where to assemble operators
  };
#endif

} // end namespace AMDiS
